# main.py

from jgtfxc import get_price_history,connect,disconnect,status

status()

connect()

d=get_price_history('EUR/USD', 'H4')
d.to_csv('../EURUSD_H4.csv')
print(d)


status()

d=get_price_history('AUD/USD', 'H4')
d.to_csv('../AUDUSD_H4.csv')
print(d)


disconnect()

status()


#import jgtfxcon

import os
import sys
sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))

import jgtconstants as constants
import jgtfxcommon as jgtfxcommon
import argparse

import JGTPDS as pds

from JGTPDS import getPH as get_price, stayConnectedSetter as set_stay_connected, disconnect,connect as on,disconnect as off, status as connection_status,  getPH2file as get_price_to_file, getPHByRange as get_price_range, stayConnectedSetter as sc,getPH as ph,getPH_to_filestore as ph2fs

import pandas as pd

def parse_args():
    parser = argparse.ArgumentParser(description='Process command parameters.')
    #jgtfxcommon.add_main_arguments(parser)
    jgtfxcommon.add_instrument_timeframe_arguments(parser)
    jgtfxcommon.add_date_arguments(parser)
    jgtfxcommon.add_max_bars_arguments(parser)
    jgtfxcommon.add_output_argument(parser)
    #jgtfxcommon.add_quiet_argument(parser)
    jgtfxcommon.add_verbose_argument(parser)
    jgtfxcommon.add_debug_argument(parser)
    jgtfxcommon.add_cds_argument(parser)
    jgtfxcommon.add_iprop_init_argument(parser)
    jgtfxcommon.add_pdsserver_argument(parser)
    args = parser.parse_args()
    return args


def main():
    args = parse_args()
    instrument = args.instrument
    timeframe = args.timeframe
    quotes_count = args.quotescount
    date_from = None
    date_to = None
    debug = args.debug
    if args.server == True:
        try:
            from . import pdsserver as svr
            svr.app.run(debug=debug)
        except:
            print("Error starting server")
            return
    if args.iprop == True:
        try:
            from . import dl_properties
            print("--------------------------------------------------")
            print("------Iprop should be downloaded in $HOME/.jgt---")
            return # we quit
        except:
            print("---BAHHHHHHHHHH Iprop trouble downloading-----")
            return
        
    if args.datefrom:
        date_from = args.datefrom # .replace('/', '.')
    if args.dateto:
        date_to = args.dateto # .replace('/', '.')

    
    output=False
    compress=False
    verbose_level = args.verbose
    quiet=False
    if verbose_level == 0:
        quiet=True
    #print("Verbose level : " + str(verbose_level))

    if args.compress:
        compress = args.compress
        output = True # in case
    if args.output:
        output = True

    if verbose_level > 1:
        if date_from:
            print("Date from : " + str(date_from))
        if date_to:
            print("Date to : " + str(date_to))


    try:
        
        print_quiet(quiet,"Getting for : " + instrument + "_" + timeframe)
        instruments = instrument.split(',')
        timeframes = timeframe.split(',')

        pds.stayConnectedSetter(True)
        for instrument in instruments:
            for timeframe in timeframes:
                if output:
                    fpath,df = pds.getPH2file(instrument, timeframe, quotes_count, date_from, date_to, False, quiet, compress)
                    print_quiet(quiet, fpath)
                else:
                    p = pds.getPH(instrument, timeframe, quotes_count, date_from, date_to, False, quiet)
                    if verbose_level > 0:
                        print(p)
        pds.disconnect()  
    except Exception as e:
        jgtfxcommon.print_exception(e)

    try:
        off()
    except Exception as e:
        jgtfxcommon.print_exception(e)

# if __name__ == "__main__":
#     main()

# print("")
# #input("Done! Press enter key to exit\n")




def print_quiet(quiet,content):
    if not quiet:
        print(content)



from typing import Callable
import threading

from . import fxcorepy


class SessionStatusListener(fxcorepy.AO2GSessionStatus):
    """The class implements the abstract class AO2GSessionStatus and calls the passed function when the session status changes."""
    def __init__(self, session: fxcorepy.O2GSession, session_id: str, pin: str,
                 on_status_changed_callback: Callable[[fxcorepy.O2GSession, fxcorepy.AO2GSessionStatus.O2GSessionStatus], None] = None)\
            -> None:
        """ The constructor.
        
            Parameters
            ----------
            session : O2GSession
                An instance of O2GSession the session status listener listens to.
            session_id : str
                The identifier of the trading session. Must be one of the values returned by the
            pin : str
                The PIN code for the connection. If no PIN is required, specify an empty string ("").
            on_session_status_changed_callback : typing.Callable[[O2GSession, AO2GSessionStatus.O2GSessionStatus], None]
                The function that is called when the session status changes.
        
            Returns
            -------
            None
        
        """
        fxcorepy.AO2GSessionStatus.__init__(self)
        self.__session = session
        self.__session_id = session_id
        self.__pin = pin
        self.__semaphore = threading.Event()
        self.set_callback(on_status_changed_callback)
        self.__connected = False
        self.__disconnected = False
        self.__last_error = None

    def wait_event(self) -> bool:
        """Reserved for future use."""
        return self.__semaphore.wait(30)

    @property
    def connected(self) -> bool:
        """ Indicates if the session status is CONNECTED.
        
            Returns
            -------
            bool
        
        """
        return self.__connected

    @property
    def disconnected(self) -> bool:
        """ Indicates if the session status is DISCONNECTED.
        
            Returns
            -------
            bool
        
        """
        return self.__disconnected

    @property
    def last_error(self) -> str:
        """ Gets the last error received by the method on_login_failed.
        
            Returns
            -------
            str
        
        """
        return self.__last_error

    def reset(self) -> None:
        """ Resets the flag that is set when the session status changes to CONNECTED or DISCONNECTED.
        
            Returns
            -------
            None
        
        """
        self.__last_error = None
        self.__semaphore.clear()

    def set_callback(self, on_status_changed_callback: Callable[[fxcorepy.O2GSession,
                                                       fxcorepy.AO2GSessionStatus.O2GSessionStatus], None]) -> None:
        """ Sets a callback function.
        
            Parameters
            ----------
            on_session_status_changed_callback : typing.Callable[[O2GSession, AO2GSessionStatus.O2GSessionStatus], None]
                The function that is called when the session status changes.
        
            Returns
            -------
            None
        
        """
        self.__on_status_changed_callback = on_status_changed_callback

    def on_session_status_changed(self, status: fxcorepy.AO2GSessionStatus.O2GSessionStatus) -> None:  # native call
        """ Implements the method AO2GSessionStatus.on_session_status_changed and calls the function that processes notifications about the session status change. The function is passed in the constructor or set by the method set_callback.
        
            Returns
            -------
            
        
        """
        self.__connected = status == fxcorepy.AO2GSessionStatus.O2GSessionStatus.CONNECTED
        self.__disconnected = status == fxcorepy.AO2GSessionStatus.O2GSessionStatus.DISCONNECTED

        if self.__on_status_changed_callback is not None:
            self.__on_status_changed_callback(self.__session, status)

        if status == fxcorepy.AO2GSessionStatus.O2GSessionStatus.CONNECTED or \
                status == fxcorepy.AO2GSessionStatus.O2GSessionStatus.DISCONNECTED:
            self.__semaphore.set()

        if status == fxcorepy.AO2GSessionStatus.O2GSessionStatus.TRADING_SESSION_REQUESTED:
            if self.__session_id != "":
                self.__session.set_trading_session(self.__session_id, self.__pin)

    def on_login_failed(self, err: str) -> None:
        """ Implements the method AO2GSessionStatus.on_login_failed and saves the error in case of a failed login.
        
            Returns
            -------
            
        
        """
        self.__last_error = err



import os
import platform
import sys
import warnings

with warnings.catch_warnings():
    warnings.filterwarnings("ignore", ".*already registered; second conversion method ignored.*")
    # your code here

origin_work_dir = os.getcwd()
here = os.path.abspath(os.path.dirname(__file__))

os.chdir(here)

lib_path = os.path.join(here, "lib")

if platform.system() == 'Windows':
    print("----------------Windows------------")
    lib_path = os.path.join(here, 'lib', 'windows')
    os.chdir(lib_path)
    #os.add_dll_directory(lib_path)
    # sys.path.append(lib_path)
    # os.environ['PATH'] += os.pathsep + lib_path  # Add lib_path to PATH
    #from .lib.windows import ForexConnect as fxfuck
    #print(lib_path)
    try:
    #      #import forexconnect
        from .lib.windows import fxcorepy as fxcorepy
    except:
        pass
        #from . import fxcorepy
         
    # from .lib.windows import *
elif platform.system() == 'Linux':
    #print("----------------Linux------------")
    lib_path = os.path.join(here, 'lib', 'linux')
    os.chdir(lib_path)
    try:
         #import forexconnect
         from .lib.linux import fxcorepy as fxcorepy
    except:
        try:
            print("-----------EXCEPTION --- #import forexconnect")
            print("---from .lib.linux import fxcorepy as fxcorepy---")
            #import jgtfxcon.forexconnect as forexconnect
            from jgtfxcon.forexconnect.lib.linux import fxcorepy as fxcorepy
        except:
            from . import fxcorepy
        
else:
    raise RuntimeError('Unsupported platform')

#print(lib_path)
os.chdir(here)
os.chdir(origin_work_dir)

#from .lib import fxcorepy
from .ForexConnect import ForexConnect
from .TableManagerListener import TableManagerListener
from .SessionStatusListener import SessionStatusListener
from .LiveHistory import LiveHistoryCreator
from .EachRowListener import EachRowListener
from .ResponseListener import ResponseListener, ResponseListenerAsync
from .TableListener import TableListener
from .common import Common

fxcorepy.O2GTransport.set_transport_modules_path(lib_path)

os.chdir(origin_work_dir)   
